==> gst-plugins-bad1.0_1.0.5.orig.tar.xz: gst-plugins-bad-1.0.5/sys/opensles/openslessrc.h <==
/* GStreamer
 * Copyright (C) 2012 Fluendo S.A. <support@fluendo.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __OPENSLESSRC_H__
#define __OPENSLESSRC_H__

#include <gst/gst.h>
#include <gst/audio/gstbaseaudiosrc.h>
#include "openslesringbuffer.h"

G_BEGIN_DECLS

#define GST_TYPE_OPENSLES_SRC \
  (gst_opensles_src_get_type())
#define GST_OPENSLES_SRC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_OPENSLES_SRC,GstOpenSLESSrc))
#define GST_OPENSLES_SRC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_OPENSLES_SRC,GstOpenSLESSrcClass))

typedef struct _GstOpenSLESSrc GstOpenSLESSrc;
typedef struct _GstOpenSLESSrcClass GstOpenSLESSrcClass;

struct _GstOpenSLESSrc
{
  GstBaseAudioSrc src;
};

struct _GstOpenSLESSrcClass
{
  GstBaseAudioSrcClass parent_class;
};

GType gst_opensles_src_get_type (void);

G_END_DECLS
#endif /* __OPENSLESSRC_H__ */

==> gst-plugins-bad1.0_1.0.8.orig.tar.xz: gst-plugins-bad-1.0.8/sys/opensles/openslessrc.h <==
/* GStreamer
 * Copyright (C) 2012 Fluendo S.A. <support@fluendo.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __OPENSLESSRC_H__
#define __OPENSLESSRC_H__

#include <gst/gst.h>
#include <gst/audio/gstaudiobasesrc.h>
#include "openslesringbuffer.h"

G_BEGIN_DECLS

#define GST_TYPE_OPENSLES_SRC \
  (gst_opensles_src_get_type())
#define GST_OPENSLES_SRC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_OPENSLES_SRC,GstOpenSLESSrc))
#define GST_OPENSLES_SRC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_OPENSLES_SRC,GstOpenSLESSrcClass))

typedef struct _GstOpenSLESSrc GstOpenSLESSrc;
typedef struct _GstOpenSLESSrcClass GstOpenSLESSrcClass;

struct _GstOpenSLESSrc
{
  GstAudioBaseSrc src;
};

struct _GstOpenSLESSrcClass
{
  GstAudioBaseSrcClass parent_class;
};

GType gst_opensles_src_get_type (void);

G_END_DECLS
#endif /* __OPENSLESSRC_H__ */
